@@ -10,7 +10,7 @@ format_by_type <- function(peak_table_path,
   if (isFALSE(grepl("https://", peak_table_path)) &&
         !file.exists(peak_table_path)) {
     cli::cli_abort("Your peak_table is not a valid file path,
-                    please eneter a new one")
+                    please enter a new one")
   }
   if (type_of_peak_table == "Progenesis") {
     return(progenesis_formatter(peak_table_path))
@@ -19,7 +19,12 @@ format_by_type <- function(peak_table_path,
   } else if (type_of_peak_table == "Metaboscape") {
     return(metaboscape_formatter(peak_table_path, sample_names))
   } else if (type_of_peak_table == "None") {
-    peak_table <- data.table(readr::read_csv(peak_table_path))
+    peak_table <- data.frame()
+    if (!(any(c("data.table", "data.frame") %in% class(peak_table_path)))) {
+      peak_table <- data.table(readr::read_csv(peak_table_path))
+    } else {
+      peak_table <- peak_table_path
+    }
     return(list(
       "peak_table" = peak_table,
       "raw_table" = peak_table
@@ -30,10 +35,12 @@ format_by_type <- function(peak_table_path,
 }
 
 progenesis_formatter <- function(peak_table) {
-  peak_table <- data.table(readr::read_csv(peak_table,
-    skip = 2,
-    show_col_types = FALSE
-  ))
+  if (!(any(c("data.table", "data.frame") %in% class(peak_table)))) {
+    peak_table <- data.table(readr::read_csv(peak_table,
+      skip = 2,
+      show_col_types = FALSE
+    ))
+  }
   raw_peak_table <- peak_table
   with(peak_table, setnames(
     peak_table,
@@ -49,10 +56,12 @@ progenesis_formatter <- function(peak_table) {
 
 
 mz_mine_formatter <- function(peak_table) {
-  peak_table <- data.table(readr::read_csv(peak_table,
-    skip = 2,
-    show_col_types = FALSE
-  ))
+  if (!(any(c("data.table", "data.frame") %in% class(peak_table)))) {
+    peak_table <- data.table(readr::read_csv(peak_table,
+      skip = 2,
+      show_col_types = FALSE
+    ))
+  }
   raw_peak_table <- peak_table
 
   return(list(
@@ -60,8 +69,12 @@ mz_mine_formatter <- function(peak_table) {
     "raw_table" = raw_peak_table
   ))
 }
+
 metaboscape_formatter <- function(peak_table, sample_names) {
-  peak_table <- data.table(readr::read_csv(peak_table, show_col_types = FALSE))
+  if (!(any(c("data.table", "data.frame") %in% class(peak_table)))) {
+    peak_table <- data.table(readr::read_csv(peak_table,
+                                             show_col_types = FALSE))
+  }
   peak_table_convert <- data.table::copy(peak_table)
   peak_table_convert <- with(peak_table_convert, peak_table_convert[
     , ion := gsub(
